==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__log.js <==
var group__spa__log =
[
    [ "spa_log", "structspa__log.html", [
      [ "iface", "structspa__log.html#a2904120a458d402fce2b316280f677c6", null ],
      [ "level", "structspa__log.html#aeb76fd47b796f30c75d48512b390cedb", null ]
    ] ],
    [ "spa_log_topic", "structspa__log__topic.html", [
      [ "has_custom_level", "structspa__log__topic.html#a1295d4049013c031f7c30074182dfe58", null ],
      [ "level", "structspa__log__topic.html#a23fb58684c75ff5cadeda72fa6ea1f92", null ],
      [ "topic", "structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6", null ],
      [ "version", "structspa__log__topic.html#a03003ed60b6acc4788b41e74b9945911", null ]
    ] ],
    [ "spa_log_methods", "structspa__log__methods.html", [
      [ "log", "structspa__log__methods.html#a7d45621105c15f6dca5549c8cc6920b7", null ],
      [ "logt", "structspa__log__methods.html#a36c36dd974369f8c679c3191399a4ab4", null ],
      [ "logtv", "structspa__log__methods.html#aeab0c4322dacb80bfd82b4de6081e025", null ],
      [ "logv", "structspa__log__methods.html#a5b42d0cf1f39f36bb70f513de84e3ece", null ],
      [ "topic_init", "structspa__log__methods.html#a51595ad4d11e427ae19bb28502d96b13", null ],
      [ "version", "structspa__log__methods.html#a3c9b289423cdd729b13d7b3311f1a637", null ]
    ] ],
    [ "SPA_KEY_LOG_COLORS", "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e", null ],
    [ "SPA_KEY_LOG_FILE", "group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a", null ],
    [ "SPA_KEY_LOG_LEVEL", "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6", null ],
    [ "SPA_KEY_LOG_LINE", "group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018", null ],
    [ "SPA_KEY_LOG_PATTERNS", "group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79", null ],
    [ "SPA_KEY_LOG_TIMESTAMP", "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14", null ],
    [ "spa_log_debug", "group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72", null ],
    [ "spa_log_error", "group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4", null ],
    [ "SPA_LOG_IMPL", "group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f", null ],
    [ "SPA_LOG_IMPL_DEFINE", "group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1", null ],
    [ "SPA_LOG_IMPL_INIT", "group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67", null ],
    [ "spa_log_info", "group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6", null ],
    [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
    [ "spa_log_level_topic_enabled", "group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6", null ],
    [ "spa_log_log", "group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2", null ],
    [ "spa_log_logt", "group__spa__log.html#gafa9a4c220c748c40bfa06de50c834416", null ],
    [ "spa_log_logtv", "group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1", null ],
    [ "spa_log_logv", "group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db", null ],
    [ "SPA_LOG_TOPIC", "group__spa__log.html#ga3442b393034c388313d9251a2cea7188", null ],
    [ "SPA_LOG_TOPIC_DEFAULT", "group__spa__log.html#ga0b5b333c2b7fbc5470f7ec68944e20a1", null ],
    [ "spa_log_topic_init", "group__spa__log.html#gac791827eec92f1c14c2fe712cf95fc69", null ],
    [ "spa_log_trace", "group__spa__log.html#ga142802024be8a40bef345806d498d6b6", null ],
    [ "spa_log_trace_fp", "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8", null ],
    [ "spa_log_warn", "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620", null ],
    [ "spa_logt_debug", "group__spa__log.html#gadb7117c17ee965bf745dd919800ba060", null ],
    [ "spa_logt_error", "group__spa__log.html#gad713020cdea3eba904cfe2ce3b0c2a42", null ],
    [ "spa_logt_info", "group__spa__log.html#ga4d1859244f14f1c31f0f5e446bed3cfc", null ],
    [ "spa_logt_trace", "group__spa__log.html#ga24e95908846b410227578abfc63b0bf0", null ],
    [ "spa_logt_warn", "group__spa__log.html#gabcb64e94f29685ea7c529aac6a2c7b68", null ],
    [ "SPA_TYPE_INTERFACE_Log", "group__spa__log.html#gaae4067126110801d47890be91be83c5e", null ],
    [ "spa_log_level", "group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d", [
      [ "SPA_LOG_LEVEL_NONE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd", null ],
      [ "SPA_LOG_LEVEL_ERROR", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114", null ],
      [ "SPA_LOG_LEVEL_WARN", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64", null ],
      [ "SPA_LOG_LEVEL_INFO", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f", null ],
      [ "SPA_LOG_LEVEL_DEBUG", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034", null ],
      [ "SPA_LOG_LEVEL_TRACE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662", null ]
    ] ],
    [ "spa_log_impl_log", "group__spa__log.html#ga3ffa62bd1aa9a79fc65062d141cd4b4f", null ],
    [ "spa_log_impl_logt", "group__spa__log.html#ga9065ed2fbfdda1b3196885c74250c5b8", null ],
    [ "spa_log_impl_logtv", "group__spa__log.html#ga5d7ac1cf2e8f86cb4d1fc55b60e558c6", null ],
    [ "spa_log_impl_logv", "group__spa__log.html#gac0dca8f108e95ac22351c85cf6134082", null ],
    [ "spa_log_impl_topic_init", "group__spa__log.html#ga53f6a1e587c688fe1a7593a61831da16", null ]
];

==> pipewire-docs-1%3A0.3.81-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__log.js <==
var group__spa__log =
[
    [ "log-impl.h", "log-impl_8h.html", null ],
    [ "log.h", "spa_2include_2spa_2support_2log_8h.html", null ],
    [ "spa_log", "structspa__log.html", [
      [ "iface", "structspa__log.html#a2904120a458d402fce2b316280f677c6", null ],
      [ "level", "structspa__log.html#aeb76fd47b796f30c75d48512b390cedb", null ]
    ] ],
    [ "spa_log_topic", "structspa__log__topic.html", [
      [ "version", "structspa__log__topic.html#a03003ed60b6acc4788b41e74b9945911", null ],
      [ "topic", "structspa__log__topic.html#ab77cbaf7b01d2f4dddbcf7f51766b9d6", null ],
      [ "level", "structspa__log__topic.html#a23fb58684c75ff5cadeda72fa6ea1f92", null ],
      [ "has_custom_level", "structspa__log__topic.html#a1295d4049013c031f7c30074182dfe58", null ]
    ] ],
    [ "spa_log_methods", "structspa__log__methods.html", [
      [ "version", "structspa__log__methods.html#a3c9b289423cdd729b13d7b3311f1a637", null ],
      [ "log", "structspa__log__methods.html#a7d45621105c15f6dca5549c8cc6920b7", null ],
      [ "logv", "structspa__log__methods.html#a5b42d0cf1f39f36bb70f513de84e3ece", null ],
      [ "logt", "structspa__log__methods.html#a36c36dd974369f8c679c3191399a4ab4", null ],
      [ "logtv", "structspa__log__methods.html#aeab0c4322dacb80bfd82b4de6081e025", null ],
      [ "topic_init", "structspa__log__methods.html#a51595ad4d11e427ae19bb28502d96b13", null ]
    ] ],
    [ "SPA_LOG_IMPL_DEFINE", "group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1", null ],
    [ "SPA_LOG_IMPL_INIT", "group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67", null ],
    [ "SPA_LOG_IMPL", "group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f", null ],
    [ "SPA_LOG_TOPIC_DEFAULT", "group__spa__log.html#ga0b5b333c2b7fbc5470f7ec68944e20a1", null ],
    [ "SPA_TYPE_INTERFACE_Log", "group__spa__log.html#gaae4067126110801d47890be91be83c5e", null ],
    [ "SPA_VERSION_LOG", "group__spa__log.html#gab60b078a5687f091f11d951899e7c270", null ],
    [ "SPA_VERSION_LOG_TOPIC", "group__spa__log.html#ga3ad08caaedbf23933f4c994cc732ca28", null ],
    [ "SPA_VERSION_LOG_METHODS", "group__spa__log.html#ga750a6ac2af9bf84c4b59af14d6cbe22f", null ],
    [ "SPA_LOG_TOPIC", "group__spa__log.html#ga3442b393034c388313d9251a2cea7188", null ],
    [ "spa_log_topic_init", "group__spa__log.html#gac791827eec92f1c14c2fe712cf95fc69", null ],
    [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
    [ "spa_log_level_topic_enabled", "group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6", null ],
    [ "spa_log_logt", "group__spa__log.html#gafa9a4c220c748c40bfa06de50c834416", null ],
    [ "spa_log_logtv", "group__spa__log.html#ga9b5e43d9eae0e03aba5f126d31839cf1", null ],
    [ "spa_logt_lev", "group__spa__log.html#ga0adfc889b560d62cbb2e6f8aa6c209b2", null ],
    [ "spa_log_lev", "group__spa__log.html#gae788ec36d61ff6a6bde516d50840999e", null ],
    [ "spa_log_log", "group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2", null ],
    [ "spa_log_logv", "group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db", null ],
    [ "spa_log_error", "group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4", null ],
    [ "spa_log_warn", "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620", null ],
    [ "spa_log_info", "group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6", null ],
    [ "spa_log_debug", "group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72", null ],
    [ "spa_log_trace", "group__spa__log.html#ga142802024be8a40bef345806d498d6b6", null ],
    [ "spa_logt_error", "group__spa__log.html#gad713020cdea3eba904cfe2ce3b0c2a42", null ],
    [ "spa_logt_warn", "group__spa__log.html#gabcb64e94f29685ea7c529aac6a2c7b68", null ],
    [ "spa_logt_info", "group__spa__log.html#ga4d1859244f14f1c31f0f5e446bed3cfc", null ],
    [ "spa_logt_debug", "group__spa__log.html#gadb7117c17ee965bf745dd919800ba060", null ],
    [ "spa_logt_trace", "group__spa__log.html#ga24e95908846b410227578abfc63b0bf0", null ],
    [ "spa_log_trace_fp", "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8", null ],
    [ "SPA_KEY_LOG_LEVEL", "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6", null ],
    [ "SPA_KEY_LOG_COLORS", "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e", null ],
    [ "SPA_KEY_LOG_FILE", "group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a", null ],
    [ "SPA_KEY_LOG_TIMESTAMP", "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14", null ],
    [ "SPA_KEY_LOG_LINE", "group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018", null ],
    [ "SPA_KEY_LOG_PATTERNS", "group__spa__log.html#ga7d4019336333f5cdf8b82514a6865b79", null ],
    [ "spa_log_level", "group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d", [
      [ "SPA_LOG_LEVEL_NONE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd", null ],
      [ "SPA_LOG_LEVEL_ERROR", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114", null ],
      [ "SPA_LOG_LEVEL_WARN", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64", null ],
      [ "SPA_LOG_LEVEL_INFO", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0575748692644545c2e6177ce3cf8a6f", null ],
      [ "SPA_LOG_LEVEL_DEBUG", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034", null ],
      [ "SPA_LOG_LEVEL_TRACE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662", null ]
    ] ],
    [ "spa_log_impl_logtv", "group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8", null ],
    [ "spa_log_impl_logt", "group__spa__log.html#ga73863d235426379d73a1defd3191877c", null ],
    [ "spa_log_impl_logv", "group__spa__log.html#gac7db20d119aac7855ba0964b7f997456", null ],
    [ "spa_log_impl_log", "group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d", null ],
    [ "spa_log_impl_topic_init", "group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1", null ]
];
